@@ -2,7 +2,7 @@
 from django.core.management import execute_manager
 
 import os, sys
-sys.path += [os.path.abspath(os.path.join(os.path.dirname(__file__), '..'))]
+sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
 
 try:
     #noinspection PyUnresolvedReferences
